.. -*- coding: utf-8 -*-

=================================
``pybill.lib.accounting`` package
=================================

.. automodule:: pybill.lib.accounting

``generator`` module
====================

.. automodule:: pybill.lib.accounting.generator

``utils`` module
================

.. automodule:: pybill.lib.accounting.utils
